@@ -46,6 +46,13 @@ def pytest_addoption(parser: pytest.Parser) -> None:
         default=False,
         help="Disables subtest output 'dots' in non-verbose mode (EXPERIMENTAL)",
     )
+    group.addoption(
+        "--no-subtests-reports",
+        action="store_true",
+        dest="no_subtests_reports",
+        default=False,
+        help="Disables subtest output unless it's a failed subtest (EXPERIMENTAL)",
+    )
 
 
 @attr.s
@@ -459,9 +466,12 @@ def pytest_report_teststatus(
 
     outcome = report.outcome
     description = report.sub_test_description()
+    no_output = ("", "", "")
 
     if hasattr(report, "wasxfail"):
-        if outcome == "skipped":
+        if config.option.no_subtests_reports and outcome != "skipped":
+            return no_output
+        elif outcome == "skipped":
             category = "xfailed"
             short = "y"  # x letter is used for regular xfail, y for subtest xfail
             status = "SUBXFAIL"
@@ -476,6 +486,9 @@ def pytest_report_teststatus(
             return None
         short = "" if config.option.no_subtests_shortletter else short
         return f"subtests {category}", short, f"{description} {status}"
+
+    if config.option.no_subtests_reports and outcome != "failed":
+        return no_output
     elif report.passed:
         short = "" if config.option.no_subtests_shortletter else ","
         return f"subtests {outcome}", short, f"{description} SUBPASS"
